<!-- Start Wrapper  -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
  <tr>
    <td align="center">

      <!-- Start Container  -->
      <table width="450" cellpadding="0" cellspacing="0" border="0" class="container">
        <tr>
          <td width="230" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

            <!-- Start Button -->
            <table cellpadding="0" cellspacing="0" border="0" width="150" height="36" bgcolor="#000000">
              <tr>
                <td valign="middle" height="36" style="font-family: Arial, sans-serif; font-size:14px; font-weight:bold;" align="center">
                  <a href="#" target="_blank" style="font-family: Arial, sans-serif; color:#ffffff; display: inline-block; text-decoration: none; line-height:36px; width:150px; font-weight:bold;">My Button &gt;</a>
                </td>
              </tr>
            </table>
            <!-- End Button -->

          </td>
          <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn">&nbsp;</td>
          <td width="230" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

            <!-- Start Button -->
            <table align="center" cellpadding="0" cellspacing="0" border="0" width="150" height="36" bgcolor="#000000">
              <tr>
                <td valign="middle" height="36" style="font-family: Arial, sans-serif; font-size:14px; font-weight:bold;" align="center">
                  <a href="#" target="_blank" style="font-family: Arial, sans-serif; color:#ffffff; display: inline-block; text-decoration: none; line-height:36px; width:150px; font-weight:bold;">My Button &gt;</a>
                </td>
              </tr>
            </table>
            <!-- End Button -->

          </td>
        </tr>
      </table>
      <!-- End Container  -->

    </td>
  </tr>
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
</table>
<!-- End Wrapper  -->
