<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
    <title>Module Master Template</title>
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, user-scalable=0" />
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
    <!--[if !mso]><!-->
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <!--<![endif]-->

    <style type="text/css">

    .ReadMsgBody { width: 100%; background-color: #F6F6F6; }
    .ExternalClass { width: 100%; background-color: #F6F6F6; }
    body { width: 100%; background-color: #f6f6f6; margin: 0; padding: 0; -webkit-font-smoothing: antialiased; font-family: Arial, Times, serif }
    table { border-collapse: collapse !important; mso-table-lspace: 0pt; mso-table-rspace: 0pt; }

    @-ms-viewport{ width: device-width; }

    @media only screen and (max-width: 639px){
    .wrapper{ width:100%;  padding: 0 !important; }
    }

    @media only screen and (max-width: 480px){
    .centerClass{ margin:0 auto !important; }
    .imgClass{ width:100% !important; height:auto; }
    .wrapper{ width:320px; padding: 0 !important; }
    .header{ width:320px; padding: 0 !important; background-image: url(http://placehold.it/320x400) !important; }
    .container{ width:300px;  padding: 0 !important; }
    .mobile{ width:300px; display:block; padding: 0 !important; text-align:center !important;}
    .mobile50{ width:300px; padding: 0 !important; text-align:center; }
    *[class="mobileOff"] { width: 0px !important; display: none !important; }
    *[class*="mobileOn"] { display: block !important; max-height:none !important; }
    }

   </style>

    <!--[if gte mso 15]>
    <style type="text/css">
        table { font-size:1px; line-height:0; mso-margin-top-alt:1px;mso-line-height-rule: exactly; }
        * { mso-line-height-rule: exactly; }
    </style>
    <![endif]-->

</head>
<body marginwidth="0" marginheight="0" leftmargin="0" topmargin="0" style="background-color:#f6f6f6;
font-family:Arial,serif; margin:0; padding:0; min-width:100%; -webkit-text-size-adjust:none; -ms-text-size-adjust:none;">

    <!--[if !mso]><!-- -->
    <img style="min-width:640px; display:block; margin:0; padding:0" class="mobileOff" width="640" height="1" src="http://s14.postimg.org/7139vfhzx/spacer.gif">
    <!--<![endif]-->

    <!-- Start Background -->
    <table width="100%" cellpadding="0" cellspacing="0" border="0">
        <tr>
            <td width="100%" valign="top" align="center">

                <!-- START HEADERS -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="mobileOff" bgcolor="#f6f6f6">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" align="left" style="font-family:arial, sans-serif; font-size:12px; line-height:18px;">
                                        This is your pre header!
                                    </td>
                                    <td width="300" class="mobile" align="right" style="font-family:arial, sans-serif; font-size:12px; line-height:18px;">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#222222; text-decoration:underline;">View Online</a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" align="center">
                                        <img src="http://placehold.it/50x50" width="50" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="400" class="mobile">
                                        <img src="http://placehold.it/200x50" width="200" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                    <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"></td>
                                    <td width="200" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

                                        <table width="200" class="container" cellpadding="0" cellspacing="0" border="0" align="center">
                                            <tr>
                                                <td align="center">

                                                    <!-- Start Button -->
                                                    <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="200" height="36" bgcolor="#000000" align="center" valign="middle"
                                                            style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff;
                                                            line-height:18px;">
                                                            <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                        </table>

                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="400" class="mobile">
                                        <img src="http://placehold.it/200x50" width="200" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                    <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"></td>
                                    <td width="200" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

                                        <table width="200" class="container" cellpadding="0" cellspacing="0" border="0" align="center">
                                            <tr>
                                                <td align="center">

                                                    <img src="http://placehold.it/200x50" width="200" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />

                                                </td>
                                            </tr>
                                        </table>

                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile">
                                        <img src="http://placehold.it/200x50" width="200" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                    </td>
                                    <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"></td>
                                    <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

                                        <table width="300" class="mobile" cellpadding="0" cellspacing="0" border="0">
                                            <tr>
                                                <td width="100" align="center">
                                                    <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:none;">Link One</a>
                                                </td>
                                                <td width="100" align="center">
                                                    <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:none;">Link Two</a>
                                                </td>
                                                <td width="100" align="center">
                                                    <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:none;">Link Three</a>
                                                </td>
                                            </tr>
                                        </table>

                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- END HEADERS -->

                <!-- START NAVIGATIONS -->

                <!-- Start Wrapper -->
                <table width="100%" cellpadding="0" cellspacing="0" border="0" bgcolor="#545150">
                    <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="190" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link One</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center">|</td>
                                    <td width="190" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Two</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
                                    <td width="190" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Three</a>
                                    </td>
                                </tr>
                           </table>
                           <!-- Start Container -->

                        </td>
                   </tr>
                   <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                   </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="100%" cellpadding="0" cellspacing="0" border="0" bgcolor="#545150">
                    <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="140" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link One</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center">|</td>
                                    <td width="140" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Two</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
                                    <td width="140" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Three</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
                                    <td width="140" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Four</a>
                                    </td>
                                </tr>
                           </table>
                           <!-- Start Container -->

                        </td>
                   </tr>
                   <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                   </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="100%" cellpadding="0" cellspacing="0" border="0" bgcolor="#545150">
                    <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="110" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link One</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center">|</td>
                                    <td width="110" class="mobile50" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Two</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
                                    <td width="110" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Three</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
                                    <td width="110" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Four</a>
                                    </td>
                                    <td width="10" style="color:#666666;" align="center" class="mobileOff">|</td>
                                    <td width="110" class="mobileOff" style="font-family:arial; font-size:12px; line-height:18px; color:#FFFFFF;" align="center" valign="middle">
                                        <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:none;">Link Five</a>
                                    </td>
                                </tr>
                           </table>
                           <!-- Start Container -->

                        </td>
                   </tr>
                   <tr>
                        <td height="15" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                   </tr>
                </table>
                <!-- End Wrapper -->

                <!-- END NAVIGATIONS -->

                <!-- START HEROS -->

                <!-- Start Wrapper -->
                <table width="640" height="400" cellpadding="0" cellspacing="0" border="0" class="header" background="http://placehold.it/640x400" style="background-image: url(http://placehold.it/640x400);">
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">
                            <!--[if gte mso 9]>
                            <v:rect xmlns:v="urn:schemas-microsoft-com:vml" fill="true" stroke="false" style="width:640px">
                            <v:fill type="frame" src="http://placehold.it/640x400" color="#ffffff" />
                            <v:textbox style="mso-fit-shape-to-text:true" inset="0,0,0,0">
                            <div style="font-size:1px;line-height:1px">
                            <table width="640" cellspacing="0" cellpadding="0" border="0" align="center">
                            <tbody>
                            <tr>
                            <td height="400" align="center">
                            <![endif]-->

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                    </td>
                                </tr>
                                 <tr>
                                    <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                </tr>
                                <tr>
                                    <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                        Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed porta purus porttitor enim scelerisque, vel malesuada lorem mattis. Curabitur ac orci libero.
                                    </td>
                                </tr>
                                 <tr>
                                    <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                </tr>
                                <tr>
                                    <td class="mobile" style="font-size:14px; line-height:20px;">

                                        <!-- Start Button -->
                                        <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                            <tr>
                                                <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                    <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Button -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                            <!--[if gte mso 9]>
                            </td>
                            </tr>
                            </tbody>
                            </table>
                            </div>
                            </v:textbox>
                            </v:rect>
                            <![endif]-->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="mobileOff" bgcolor="#FFFFFF">
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="640" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="600" class="mobile">
                                        <img src="http://placehold.it/640x400" width="640" height="400" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!--[if !mso]><!-- -->
                <div class="mobileOn" style="font-size: 0; max-height: 0; overflow: hidden; display: none">
                    <table width="320" cellspacing="0" cellpadding="0" border="0" class="wrapper" align="center">
                        <tr>
                            <td align="center">
                                <img src="http://placehold.it/320x300" width="320" height="300" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                            </td>
                        </tr>
                    </table>
                </div>
                <!--<![endif]-->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper">
                                <tr>
                                    <td width="640" class="wrapper">
                                        <img src="http://placehold.it/640x400" width="640" height="400" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- END HEROS -->

                <!-- START CONTENT PANELS -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" align="center" border="0" class="wrapper" bgcolor="#ffffff">
                    <tbody>
                        <tr>
                            <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                        <tr>
                            <td align="center" bgcolor="#ffffff">

                                <!-- Start Container -->
                                <table width="600" cellpadding="0" cellspacing="0" align="center" border="0" class="container">
                                    <tr>
                                        <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                            Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                        </td>
                                    </tr>
                                    <tr>
                                        <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                                    </tr>
                                    <tr>
                                        <td align="center" style="font-family:Verdana, Arial, sans serif; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                            Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos.
                                            <a href="" target="_blank" alias="" style="color: #000000; text-decoration: none; font-weight: bold; text-decoration:underline;">this is a link!</a>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                                    </tr>
                                    <tr>
                                        <td align="center" class="center">

                                            <!-- Start Button -->
                                            <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                <tr>
                                                    <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                        <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                    </td>
                                                </tr>
                                            </table>
                                            <!-- End Button -->

                                        </td>
                                    </tr>
                                </table>
                                <!-- End Container -->

                            </td>
                        </tr>
                        <tr>
                            <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                    </tbody>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="FFFFFF">
                    <tr>
                        <td height="20" style="font-size:20px; line-height:20px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="600" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="290" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                                            <tr>
                                                <td width="600" class="mobile" style="font-size:12px; line-height:18px;" align="center">
                                                    <img src="http://www.placehold.it/600x300" width="600" height="300" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                                    Title One
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                             <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="FFFFFF">
                    <tr>
                        <td height="20" style="font-size:20px; line-height:20px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="290" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                                            <tr>
                                                <td width="290" class="mobile" style="font-size:12px; line-height:18px;" align="center">
                                                    <img src="http://www.placehold.it/290x200" width="290" height="200" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                                    Title One
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                             <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                    <td width="300" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="290" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                                            <tr>
                                                <td width="290" class="mobile" style="font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/290x200" width="290" height="200" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                                    Title Two
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="FFFFFF">
                    <tr>
                        <td height="20" style="font-size:20px; line-height:20px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="200" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="190" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                                            <tr>
                                                <td width="190" class="mobile" style="font-size:12px; line-height:18px;" align="center">
                                                    <img src="http://www.placehold.it/190x100" width="190" height="100" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                                    Title One
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="190" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="190" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                             <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                    <td width="200" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="190" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                                            <tr>
                                                <td width="190" class="mobile" style="font-size:12px; line-height:18px;">
                                                    <img src="http://www.placehold.it/190x100" width="190" height="100" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                                    Title Two
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="190" class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="190" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="190" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                    <td width="200" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="190" cellpadding="0" cellspacing="0" border="0" class="container" align="center">
                                            <tr>
                                                <td width="190" class="mobile" style="font-size:12px; line-height:18px;" align="center">
                                                    <img src="http://www.placehold.it/190x100" width="190" height="100" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                                    Title Three
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="200" class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="190" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="190" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" align="center" valign="top">

                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container" align="left">
                                            <tr>
                                                <td width="280" class="mobile" style="font-size:12px; line-height:18px;">
                                                    <img src="http://placehold.it/280x210" width="280" height="210" style="margin:0; padding:0; border:none; display:block;" alt="" class="imgClass" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;" class="mobileOn"> </td><!-- Spacer -->
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                    <td width="300" class="mobile" align="center" valign="top">

                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container" align="right">
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;" align="center">
                                                    Lorem ipsum dolor sit.
                                                </td>
                                            </tr>
                                             <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="280" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;" align="center">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed porta purus porttitor enim scelerisque, vel malesuada lorem mattis. Curabitur ac orci libero. Vel malesuada lorem mattis. Curabitur.
                                                </td>
                                            </tr>
                                             <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="280" class="mobile" style="font-size:14px; line-height:20px;" align="center">

                                                    <!-- Start Button -->
                                                    <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td align="center">

                            <!-- Start Container -->
                            <table width="640" cellpadding="0" cellspacing="0" border="0" class="container" bgcolor="#222222">
                                <tr>
                                    <td width="320" height="250" class="mobile" style="font-size:12px; line-height:18px;" align="center">
                                        <img src="http://placehold.it/320x250" width="320" height="250" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
                                    </td>
                                    <td width="320" height="250" class="mobile" style="font-size:12px; line-height:18px;" align="center">

                                        <!-- Start Content -->
                                        <table width="280" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="280" align="center" class="mobile" style="font-family:arial, sans,serif; font-size:20px; line-height:26px; font-weight:bold; color:#FFFFFF;">
                                                    The Title
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="280" align="center" class="mobile" style="font-family:arial, sans,serif; font-size:14px; line-height:20px; color:#CCCCCC;">
                                                    Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed porta purus porttitor enim scelerisque, vel malesuada lorem mattis. Curabitur ac orci libero.
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="25" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                                            </tr>
                                            <tr>
                                                <td width="280" class="mobile" style="font-size:14px; line-height:20px;">

                                                    <!-- Start Button -->
                                                    <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                                                        <tr>
                                                            <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                            </td>
                                                        </tr>
                                                    </table>
                                                    <!-- End Button -->

                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Content -->

                                    </td>
                                </tr>
                            </table>
                            <!-- End Container -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#F9F9F9" st-options="edit" align="center">
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td align="center">

                                        <!-- Start Container  -->
                                        <table width="408" cellpadding="0" cellspacing="0" border="0" class="container">
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> &nbsp;</td>
                                            </tr>
                                            <tr>
                                                <td width="68" class="mobile50" align="center">
                                                    <img src="http://placehold.it/32x32" width="32" height="32" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                                </td>
                                                <td width="68" class="mobile50" align="center">
                                                    <img src="http://placehold.it/32x32" width="32" height="32" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                                </td>
                                                <td width="68" class="mobile50" align="center">
                                                    <img src="http://placehold.it/32x32" width="32" height="32" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                                </td>
                                                <td width="68" class="mobile50" align="center">
                                                    <img src="http://placehold.it/32x32" width="32" height="32" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                                </td>
                                                <td width="68" class="mobile50" align="center">
                                                    <img src="http://placehold.it/32x32" width="32" height="32" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                                </td>
                                                <td width="68" class="mobile50" align="center">
                                                    <img src="http://placehold.it/32x32" width="32" height="32" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
                                                </td>
                                            </tr>
                                            <tr>
                                                <td height="20" style="font-size:10px; line-height:10px;"> &nbsp;</td>
                                            </tr>
                                        </table>
                                        <!-- Start Container  -->

                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- END CONTENT PANELS -->

                <!-- START BUTTONS -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#ffffff">
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Button -->
                            <table width="200" cellpadding="0" cellspacing="0" align="center" border="0">
                                <tr>
                                    <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                        <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Button -->

                            <!-- Start Button -->
                            <table width="200" cellpadding="0" cellspacing="0" border="0" align="left">
                                <tr>
                                    <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                        <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Button -->

                            <!-- Start Button -->
                            <table width="200" cellpadding="0" cellspacing="0" align="right" border="0">
                                <tr>
                                    <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px;">
                                        <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Button -->

                        </td>
                    </tr>
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="450" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="230" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

                                        <!-- Start Button -->
                                        <table width="200" cellpadding="0" cellspacing="0" align="center" border="0">
                                            <tr>
                                                <td width="200" height="36" bgcolor="#000000" align="center" valign="middle"
                                                style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff;
                                                line-height:18px;">
                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Button -->

                                    </td>
                                    <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"></td>
                                    <td width="230" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

                                        <!-- Start Button -->
                                        <table width="200" cellpadding="0" cellspacing="0" align="center" border="0">
                                            <tr>
                                                <td width="200" height="36" bgcolor="#000000" align="center" valign="middle"
                                                style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff;
                                                line-height:18px;">
                                                <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                                </td>
                                            </tr>
                                        </table>
                                        <!-- End Button -->

                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                            <!-- Start Button -->
                            <table width="200" cellpadding="0" cellspacing="0" align="center" border="0">
                                <tr>
                                    <td width="200" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff; line-height:18px; -webkit-border-radius: 50px; -moz-border-radius: 50px; border-radius: 50px; ">
                                    <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button ></a>
                                    </td>
                                </tr>
                            </table>
                            <!-- End Button -->

                        </td>
                    </tr>
                    <tr>
                        <td height="20" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                <!-- END BUTTONS -->

                <!-- START FOOTERS -->

                <!-- Start Wrapper  -->
                <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#222222">
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                    <tr>
                        <td align="center">

                            <!-- Start Container  -->
                            <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
                                <tr>
                                    <td width="300" class="mobile" style="font-family:arial, sans-serif; font-size:12px; line-height:18px; color:#FFFFFF;">
                                        &copy; 2015 Email Framework, All Rights Reversed.
                                    </td>
                                    <td width="300" class="mobile" style="font-family:arial, sans-serif; font-size:12px; line-height:18px; color:#FFFFFF;" align="right">
                                       <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#FFFFFF; text-decoration:underline;">Unsubscribe</a>
                                    </td>
                                </tr>
                            </table>
                            <!-- Start Container  -->

                        </td>
                    </tr>
                    <tr>
                        <td height="10" style="font-size:10px; line-height:10px;"> </td><!-- Spacer -->
                    </tr>
                </table>
                <!-- End Wrapper  -->

                 <!-- END FOOTERS -->

            </td>
        </tr>
    </table>
    <!-- End Background -->

</body>
</html>
