<!-- Start Wrapper -->
<table width="640" height="400" cellpadding="0" cellspacing="0" border="0" class="header" background="http://placehold.it/640x400" style="background-image: url(http://placehold.it/640x400);">
  <tr>
    <td align="center">
    <!--[if gte mso 9]>
    <v:rect xmlns:v="urn:schemas-microsoft-com:vml" fill="true" stroke="false" style="width:640px">
    <v:fill type="frame" src="http://placehold.it/640x400" color="#ffffff" />
    <v:textbox style="mso-fit-shape-to-text:true" inset="0,0,0,0">
    <div style="font-size:1px;line-height:1px">
    <table width="640" cellspacing="0" cellpadding="0" border="0" align="center">
    <tbody>
    <tr>
    <td height="400" align="center">
    <![endif]-->

    <!-- Start Container -->
    <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
      <tr>
        <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
          Testing Modules for the email framework
        </td>
      </tr>
      <tr>
        <td height="20" style="font-size:10px; line-height:10px;">&nbsp;</td>
      </tr>
      <tr>
        <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:14px; line-height:20px;">
          Lorem ipsum dolor sit amet, consectetur adipiscing elit. Sed porta purus porttitor enim scelerisque, vel malesuada lorem mattis. Curabitur ac orci libero.
        </td>
      </tr>
      <tr>
        <td height="20" style="font-size:10px; line-height:10px;">&nbsp;</td>
      </tr>
      <tr>
        <td class="mobile" style="font-size:14px; line-height:20px;" align="center">

          <!-- Start Button -->
          <table align="center" cellpadding="0" cellspacing="0" border="0" width="150" height="36" bgcolor="#000000">
            <tr>
              <td valign="middle" height="36" style="font-family: Arial, sans-serif; font-size:14px; font-weight:bold;" align="center">
                <a href="#" target="_blank" style="font-family: Arial, sans-serif; color:#ffffff; display: inline-block; text-decoration: none; line-height:36px; width:150px; font-weight:bold;">My Button &gt;</a>
              </td>
            </tr>
          </table>
          <!-- End Button -->

        </td>
      </tr>
    </table>
    <!-- End Container -->

    <!--[if gte mso 9]>
    </td>
    </tr>
    </tbody>
    </table>
    </div>
    </v:textbox>
    </v:rect>
    <![endif]-->

    </td>
  </tr>
</table>
<!-- End Wrapper -->
