<!-- Start Wrapper  -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
  <tr>
    <td align="center">

      <!-- Start Container  -->
      <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
        <tr>
          <td width="300" class="mobile">
            <img src="http://placehold.it/200x50" width="200" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
          </td>
          <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"></td>
          <td width="300" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

            <table width="300" class="mobile" cellpadding="0" cellspacing="0" border="0">
              <tr>
                <td width="100" align="center">
                  <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:none;">Link One</a>
                </td>
                <td width="100" align="center">
                  <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:none;">Link Two</a>
                </td>
                <td width="100" align="center">
                  <a href="" target="_blank" alias="" style="font-size:12px; line-height:18px; color:#525252; text-decoration:none;">Link Three</a>
                </td>
              </tr>
            </table>

          </td>
        </tr>
      </table>
      <!-- End Container  -->

    </td>
  </tr>
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
</table>
<!-- End Wrapper  -->
