    <!-- Start Wrapper -->
    <table width="640" cellpadding="0" cellspacing="0" align="center" border="0" class="wrapper" bgcolor="#ffffff">
        <tbody>
            <tr>
                <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
            </tr>
            <tr>
                <td align="center" bgcolor="#ffffff">

                    <!-- Start Container -->
                    <table width="600" cellpadding="0" cellspacing="0" align="center" border="0" class="container">
                        <tr>
                            <td align="center" class="mobile" style="font-family:arial, sans-serif; font-size:20px; line-height:26px; font-weight:bold;">
                                Lorem ipsum dolor sit amet, consectetur adipiscing elit.
                            </td>
                        </tr>
                        <tr>
                            <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                        <tr>
                            <td align="center" style="font-family:Verdana, Arial, sans serif; font-size: 14px; color: #4d4d4d; line-height:18px;">
                                Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur orci neque, efficitur sit amet luctus eget, malesuada eu turpis. Duis bibendum sem pharetra quam ullamcorper malesuada. Class aptent taciti sociosqu ad litora torquent per conubia nostra, per inceptos himenaeos.
                                <a href="" target="_blank" alias="" style="color: #000000; text-decoration: none; font-weight: bold; text-decoration:underline;">this is a link!</a>
                            </td>
                        </tr>
                        <tr>
                            <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
                        </tr>
                        <tr>
                            <td align="center" class="center">

                                <!-- Start Button -->
                                <table width="190" cellpadding="0" cellspacing="0" align="center" border="0">
                                    <tr>
                                        <td width="190" height="36" bgcolor="#000000" align="center" valign="middle" style="font-family:arial, sans-serif; font-size: 16px; color: #ffffff; line-height:18px; border-radius:3px;">
                                            <a href="" target="_blank" alias="" style="font-family:arial, sans-serif; text-decoration: none; color: #ffffff;">My Button ></a>
                                        </td>
                                    </tr>
                                </table>
                                <!-- End Button -->

                            </td>
                        </tr>
                    </table>
                    <!-- End Container -->

                </td>
            </tr>
            <tr>
                <td height="20" style="line-height:20px; font-size:20px;"> </td><!-- Spacer -->
            </tr>
        </tbody>
    </table>
    <!-- End Wrapper -->
