{% load static cms_tags sekizai_tags sass_tags i18n %}
<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}" ng-app="myShop">
<head>
    <title>Subscriptions | Shop</title>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1" />
    <meta name='viewport' content='width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=0'/>
    <meta name="description" content="confirm email subscription form" />

    {% addtoblock "css" %}<link rel="stylesheet" type="text/css" href="{% sass_src 'shop/css/_django-shop.scss' %}" />{% endaddtoblock %}
    {% render_block "ext-css" %}
    {% render_block "css" postprocessor "compressor.contrib.sekizai.compress" %}
</head>

{% addtoblock "js" %}<script src="{% static 'node_modules/picturefill/dist/picturefill.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'node_modules/angular/angular.min.js' %}" type="text/javascript"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'node_modules/angular-sanitize/angular-sanitize.min.js' %}"></script>{% endaddtoblock %}
{% addtoblock "js" %}<script src="{% static 'node_modules/angular-animate/angular-animate.min.js' %}"></script>{% endaddtoblock %}

<body class="shop_subscribe">
    {% cms_toolbar %}

    {% include "shop/breadcrumb/default.html" %}

    <div class="container">
        <div class="row">
            <div class="col-xs-12 col-sm-10 col-sm-offset-1 col-md-8 col-md-offset-2">
                {% include "shop_subscribe/confirm-form.html" %}
            </div>
        </div>
    </div>

    {% render_block "ext-js" %}
    {% render_block "js" postprocessor "compressor.contrib.sekizai.compress" %}
    <script type="text/javascript">
    angular.module('myShop', ['ngAnimate', 'ngSanitize',
        {% render_block "ng-requires" postprocessor "djng.sekizai_processors.module_list" %}
    ]).config(['$httpProvider', function($httpProvider) {
        $httpProvider.defaults.headers.common['X-CSRFToken'] = '{{ csrf_token }}';
        $httpProvider.defaults.headers.common['X-Requested-With'] = 'XMLHttpRequest';
    }]).config(['$locationProvider', function($locationProvider) {
        $locationProvider.html5Mode(false);
    }]){% render_block "ng-config" postprocessor "djng.sekizai_processors.module_config" %};
    </script>
</body>

</html>
