<!-- Start Wrapper  -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
  <tr>
    <td align="center">

      <!-- Start Container  -->
      <table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper">
        <tr>
          <td width="640" class="wrapper">
            <img src="http://placehold.it/640x400" width="640" height="400" style="margin:0; padding:0; border:none; display:block;" border="0" class="imgClass" alt="" />
          </td>
        </tr>
      </table>
      <!-- End Container -->

    </td>
  </tr>
</table>
<!-- End Wrapper  -->
