<!-- Start Wrapper  -->
<table width="640" cellpadding="0" cellspacing="0" border="0" class="wrapper" bgcolor="#FFFFFF">
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
  <tr>
    <td align="center">

      <!-- Start Container  -->
      <table width="600" cellpadding="0" cellspacing="0" border="0" class="container">
        <tr>
          <td width="400" class="mobile">
            <img src="http://placehold.it/200x50" width="200" height="50" style="margin:0; padding:0; border:none; display:block;" border="0" class="centerClass" alt="" />
          </td>
          <td height="10" style="font-size:10px; line-height:10px;" class="mobileOn"></td>
          <td width="200" class="mobile" style="font-family:arial; font-size:12px; line-height:18px;">

            <table width="200" class="container" cellpadding="0" cellspacing="0" border="0" align="center">
              <tr>
                <td align="center">

                  <!-- Start Button -->
                  <table width="200" cellpadding="0" cellspacing="0" align="center" border="0" class="centerClass">
                      <tr>
                          <td width="200" height="36" bgcolor="#000000" align="center" valign="middle"
                          style="font-family: Arial,Helvetica,sans-serif; font-size: 16px; color: #ffffff;
                          line-height:18px;">
                          <a href="" target="_blank" alias="" style="text-decoration: none; color: #ffffff;">My Button &gt;</a>
                          </td>
                      </tr>
                  </table>
                  <!-- End Button -->

                </td>
              </tr>
            </table>

          </td>
        </tr>
      </table>
      <!-- End Container  -->

    </td>
  </tr>
  <tr>
    <td height="10" style="font-size:10px; line-height:10px;">&nbsp;</td>
  </tr>
</table>
<!-- End Wrapper  -->
