<!-- Start Button -->
<table align="center" cellpadding="0" cellspacing="0" border="0" width="150" height="36" bgcolor="#ffffff" style="border:2px solid #333333;">
  <tr>
    <td valign="middle" height="36" style="font-family: Arial, sans-serif; font-size:14px; font-weight:bold;" align="center">
    	<a href="#" target="_blank" style="font-family: Arial, sans-serif; color:#333333; display: inline-block; text-decoration: none; line-height:36px; width:150px; font-weight:bold;">My Button &gt;</a>
    </td>
  </tr>
</table>
<!-- End Button -->
